@@ -28,6 +28,7 @@ import time
 import logging
 import Adafruit_PCA9685
 from .channel import Channel
+from .morse import Morse
 logging.basicConfig(level=logging.CRITICAL)
 logging.propagate = False
 
@@ -467,6 +468,23 @@ class SmarsRobot():
                     leg_minangle=9, leg_maxangle=90, invert=True))
     # print "number of legs", len(legs)
 
+    def tap_message(self, message:str):
+        """ Taps out a character """
+        self.__legs[Channel.LEFT_FOOT_FRONT].down()
+        for character in message:
+            dot = 0.25
+            dash = 0.5
+            duration = 0.0
+            for dot_dash in Morse.alphabet[character]:
+                if dot_dash == '.':
+                    duration = dot
+                if dot_dash == "-":
+                    duration = dash
+                self.__legs[Channel.LEFT_FOOT_FRONT].down()
+                time.sleep(duration)
+                self.__legs[Channel.LEFT_FOOT_FRONT].up()
+
+
     def identify(self, channel:int)->str:
         """ Identies the limb by the channel passed in, returns the limb name """
         for limb in self.__feet:
@@ -747,14 +765,14 @@ class SmarsRobot():
                     time.sleep(SLEEP_COUNT)
 
                     # Old walking code - not very clear
-                    if self.__legs[tick_count].name == 'RIGHT_LEG_FRONT':
-                        self.__legs[tick_count].stretch()
-                    if self.__legs[tick_count].name == 'LEFT_LEG_FRONT':
-                        self.__legs[tick_count].body()
-                    if self.__legs[tick_count].name == 'RiGHT_LEG_BACK':
-                        self.__legs[tick_count].body()
-                    if self.__legs[tick_count].name == 'LEFT_LEG_BACK':
-                        self.__legs[tick_count].stretch()
+                    # if self.__legs[tick_count].name == 'RIGHT_LEG_FRONT':
+                    #     self.__legs[tick_count].stretch()
+                    # if self.__legs[tick_count].name == 'LEFT_LEG_FRONT':
+                    #     self.__legs[tick_count].body()
+                    # if self.__legs[tick_count].name == 'RiGHT_LEG_BACK':
+                    #     self.__legs[tick_count].body()
+                    # if self.__legs[tick_count].name == 'LEFT_LEG_BACK':
+                    #     self.__legs[tick_count].stretch()
                     # if not self.__legs[tick_count].invert:
                     #     if self.__legs[tick_count].name == "RIGHT_LEG_FRONT":
                     #         self.__legs[tick_count].stretch()
@@ -765,6 +783,19 @@ class SmarsRobot():
                     #         self.__legs[tick_count].body()
                     #     if self.__legs[tick_count].name == "LEFT_LEG_FRONT":
                     #         self.__legs[tick_count].stretch()
+
+                    if not self.__legs[tick_count].invert:
+                        # if self.__legs[tick_count].name == "LEFT_LEG_BACK":
+                        if self.__legs[tick_count].name == "RIGHT_LEG_FRONT":
+                            self.__legs[tick_count].stretch()
+                        else:
+                            self.__legs[tick_count].body()
+                    elif self.__legs[tick_count].invert:
+                        # if self.__legs[tick_count].name == "LEFT_LEG_FRONT":
+                        if self.__legs[tick_count].name == "RIGHT_LEG_BACK":
+                            self.__legs[tick_count].body()
+                        else:
+                            self.__legs[tick_count].stretch()
                     time.sleep(SLEEP_COUNT)
                     self.__feet[tick_count].up()
                     time.sleep(SLEEP_COUNT)
